==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/widget/pending_terminal_request_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class PendingTerminalRequestSheet extends StatelessWidget {
  const PendingTerminalRequestSheet({super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(20),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Container(
                  height: 60,
                  width: 60,
                  padding: const EdgeInsets.all(14),
                  decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      color: pluginTheme.secondaryColor),
                  child: Image.asset(loadAsset("pending_icon.png"))),
              const Spacer(),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: const RoundedItemContainer(asset: "cancel_icon.png"),
              )
            ],
          ),
          const Gap(20),
          Text(
            "Pending Terminal Request",
            style: headling1.copyWith(fontSize: 20),
          ),
          const Gap(8),
          Text(
              "You have a pending terminal request, you cannot place another order for terminal request kindly reach out to our support team for any issues. support@partner.com",
              style: subtitle2.copyWith(
                  fontSize: 14, fontWeight: FontWeight.w400)),
          const Gap(44),
          RavenPayButton(
              buttonText: "Close",
              buttonColor: pluginTheme.primaryColor,
              onPressed: () async {
                Navigator.pop(context);
              }),
          const Gap(30),
        ],
      ),
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/terminal/widget/pending_terminal_request_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_terminal_details.dart';

class PendingTerminalRequestSheet extends StatelessWidget {
  const PendingTerminalRequestSheet({super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(20),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Container(
                  height: 60,
                  width: 60,
                  padding: const EdgeInsets.all(14),
                  decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      color: pluginTheme.secondaryColor),
                  child: Image.asset(loadAsset("pending_icon.png"))),
              const Spacer(),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: const RoundedItemContainer(asset: "cancel_icon.png"),
              )
            ],
          ),
          const Gap(20),
          Text(
            "Pending Terminal Request",
            style: headling1.copyWith(fontSize: 20),
          ),
          const Gap(8),
          Text(
              "You have a pending terminal request, you cannot place another order for terminal request kindly reach out to our support team for any issues. support@partner.com",
              style: subtitle2.copyWith(
                  fontSize: 14, fontWeight: FontWeight.w400)),
          const Gap(44),
          RavenPayButton(
              buttonText: "Close",
              buttonColor: pluginTheme.primaryColor,
              onPressed: () async {
                Navigator.pop(context);
              }),
          const Gap(30),
        ],
      ),
    );
  }
}
